==> gdcm-2.8.7.tgz: lib/gdcm-2.8/GDCMTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "gdcmCommon" for configuration "Release"
set_property(TARGET gdcmCommon APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmCommon PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmCommon.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmCommon )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmCommon "${_IMPORT_PREFIX}/lib/libgdcmCommon.so.0.0" )

# Import target "gdcmDICT" for configuration "Release"
set_property(TARGET gdcmDICT APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmDICT PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmDICT.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmDICT )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmDICT "${_IMPORT_PREFIX}/lib/libgdcmDICT.so.0.0" )

# Import target "gdcmDSED" for configuration "Release"
set_property(TARGET gdcmDSED APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmDSED PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmDSED.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmDSED )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmDSED "${_IMPORT_PREFIX}/lib/libgdcmDSED.so.0.0" )

# Import target "gdcmIOD" for configuration "Release"
set_property(TARGET gdcmIOD APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmIOD PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmIOD.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmIOD )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmIOD "${_IMPORT_PREFIX}/lib/libgdcmIOD.so.0.0" )

# Import target "gdcmMSFF" for configuration "Release"
set_property(TARGET gdcmMSFF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmMSFF PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gdcmjpeg8;gdcmjpeg12;gdcmjpeg16;gdcmcharls"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmMSFF.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmMSFF )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmMSFF "${_IMPORT_PREFIX}/lib/libgdcmMSFF.so.0.0" )

# Import target "gdcmMEXD" for configuration "Release"
set_property(TARGET gdcmMEXD APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmMEXD PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmMEXD.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmMEXD )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmMEXD "${_IMPORT_PREFIX}/lib/libgdcmMEXD.so.0.0" )

# Import target "gdcmjpeg8" for configuration "Release"
set_property(TARGET gdcmjpeg8 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmjpeg8 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmjpeg8.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmjpeg8 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmjpeg8 "${_IMPORT_PREFIX}/lib/libgdcmjpeg8.so.0.0" )

# Import target "gdcmjpeg12" for configuration "Release"
set_property(TARGET gdcmjpeg12 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmjpeg12 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmjpeg12.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmjpeg12 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmjpeg12 "${_IMPORT_PREFIX}/lib/libgdcmjpeg12.so.0.0" )

# Import target "gdcmjpeg16" for configuration "Release"
set_property(TARGET gdcmjpeg16 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmjpeg16 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmjpeg16.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmjpeg16 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmjpeg16 "${_IMPORT_PREFIX}/lib/libgdcmjpeg16.so.0.0" )

# Import target "gdcmcharls" for configuration "Release"
set_property(TARGET gdcmcharls APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmcharls PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmcharls.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmcharls )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmcharls "${_IMPORT_PREFIX}/lib/libgdcmcharls.so.0.0" )

# Import target "socketxx" for configuration "Release"
set_property(TARGET socketxx APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(socketxx PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libsocketxx.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS socketxx )
list(APPEND _IMPORT_CHECK_FILES_FOR_socketxx "${_IMPORT_PREFIX}/lib/libsocketxx.so.0.0" )

# Import target "gdcmdump" for configuration "Release"
set_property(TARGET gdcmdump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmdump PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmdump"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmdump )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmdump "${_IMPORT_PREFIX}/bin/gdcmdump" )

# Import target "gdcmdiff" for configuration "Release"
set_property(TARGET gdcmdiff APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmdiff PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmdiff"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmdiff )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmdiff "${_IMPORT_PREFIX}/bin/gdcmdiff" )

# Import target "gdcmraw" for configuration "Release"
set_property(TARGET gdcmraw APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmraw PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmraw"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmraw )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmraw "${_IMPORT_PREFIX}/bin/gdcmraw" )

# Import target "gdcmscanner" for configuration "Release"
set_property(TARGET gdcmscanner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmscanner PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmscanner"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmscanner )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmscanner "${_IMPORT_PREFIX}/bin/gdcmscanner" )

# Import target "gdcmanon" for configuration "Release"
set_property(TARGET gdcmanon APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmanon PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmanon"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmanon )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmanon "${_IMPORT_PREFIX}/bin/gdcmanon" )

# Import target "gdcmgendir" for configuration "Release"
set_property(TARGET gdcmgendir APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmgendir PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmgendir"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmgendir )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmgendir "${_IMPORT_PREFIX}/bin/gdcmgendir" )

# Import target "gdcmimg" for configuration "Release"
set_property(TARGET gdcmimg APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmimg PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmimg"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmimg )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmimg "${_IMPORT_PREFIX}/bin/gdcmimg" )

# Import target "gdcmconv" for configuration "Release"
set_property(TARGET gdcmconv APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmconv PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmconv"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmconv )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmconv "${_IMPORT_PREFIX}/bin/gdcmconv" )

# Import target "gdcmtar" for configuration "Release"
set_property(TARGET gdcmtar APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmtar PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmtar"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmtar )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmtar "${_IMPORT_PREFIX}/bin/gdcmtar" )

# Import target "gdcminfo" for configuration "Release"
set_property(TARGET gdcminfo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcminfo PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcminfo"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcminfo )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcminfo "${_IMPORT_PREFIX}/bin/gdcminfo" )

# Import target "gdcmscu" for configuration "Release"
set_property(TARGET gdcmscu APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmscu PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmscu"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmscu )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmscu "${_IMPORT_PREFIX}/bin/gdcmscu" )

# Import target "gdcmxml" for configuration "Release"
set_property(TARGET gdcmxml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmxml PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmxml"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmxml )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmxml "${_IMPORT_PREFIX}/bin/gdcmxml" )

# Import target "gdcmpap3" for configuration "Release"
set_property(TARGET gdcmpap3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmpap3 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmpap3"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmpap3 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmpap3 "${_IMPORT_PREFIX}/bin/gdcmpap3" )

# Import target "gdcmpdf" for configuration "Release"
set_property(TARGET gdcmpdf APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmpdf PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmpdf"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmpdf )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmpdf "${_IMPORT_PREFIX}/bin/gdcmpdf" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> gdcm-3.0.2.tgz: lib/gdcm-3.0/GDCMTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "gdcmjpeg8" for configuration "Release"
set_property(TARGET gdcmjpeg8 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmjpeg8 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmjpeg8.so.1.0"
  IMPORTED_SONAME_RELEASE "libgdcmjpeg8.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmjpeg8 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmjpeg8 "${_IMPORT_PREFIX}/lib/libgdcmjpeg8.so.1.0" )

# Import target "gdcmjpeg12" for configuration "Release"
set_property(TARGET gdcmjpeg12 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmjpeg12 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmjpeg12.so.1.0"
  IMPORTED_SONAME_RELEASE "libgdcmjpeg12.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmjpeg12 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmjpeg12 "${_IMPORT_PREFIX}/lib/libgdcmjpeg12.so.1.0" )

# Import target "gdcmjpeg16" for configuration "Release"
set_property(TARGET gdcmjpeg16 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmjpeg16 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmjpeg16.so.1.0"
  IMPORTED_SONAME_RELEASE "libgdcmjpeg16.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmjpeg16 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmjpeg16 "${_IMPORT_PREFIX}/lib/libgdcmjpeg16.so.1.0" )

# Import target "gdcmcharls" for configuration "Release"
set_property(TARGET gdcmcharls APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmcharls PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmcharls.so.1.0"
  IMPORTED_SONAME_RELEASE "libgdcmcharls.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmcharls )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmcharls "${_IMPORT_PREFIX}/lib/libgdcmcharls.so.1.0" )

# Import target "socketxx" for configuration "Release"
set_property(TARGET socketxx APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(socketxx PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libsocketxx.so.1.0"
  IMPORTED_SONAME_RELEASE "libsocketxx.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS socketxx )
list(APPEND _IMPORT_CHECK_FILES_FOR_socketxx "${_IMPORT_PREFIX}/lib/libsocketxx.so.1.0" )

# Import target "gdcmCommon" for configuration "Release"
set_property(TARGET gdcmCommon APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmCommon PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmCommon.so.1.0"
  IMPORTED_SONAME_RELEASE "libgdcmCommon.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmCommon )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmCommon "${_IMPORT_PREFIX}/lib/libgdcmCommon.so.1.0" )

# Import target "gdcmDICT" for configuration "Release"
set_property(TARGET gdcmDICT APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmDICT PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmDICT.so.1.0"
  IMPORTED_SONAME_RELEASE "libgdcmDICT.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmDICT )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmDICT "${_IMPORT_PREFIX}/lib/libgdcmDICT.so.1.0" )

# Import target "gdcmDSED" for configuration "Release"
set_property(TARGET gdcmDSED APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmDSED PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmDSED.so.1.0"
  IMPORTED_SONAME_RELEASE "libgdcmDSED.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmDSED )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmDSED "${_IMPORT_PREFIX}/lib/libgdcmDSED.so.1.0" )

# Import target "gdcmIOD" for configuration "Release"
set_property(TARGET gdcmIOD APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmIOD PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmIOD.so.1.0"
  IMPORTED_SONAME_RELEASE "libgdcmIOD.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmIOD )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmIOD "${_IMPORT_PREFIX}/lib/libgdcmIOD.so.1.0" )

# Import target "gdcmMSFF" for configuration "Release"
set_property(TARGET gdcmMSFF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmMSFF PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gdcmjpeg8;gdcmjpeg12;gdcmjpeg16;gdcmcharls"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmMSFF.so.1.0"
  IMPORTED_SONAME_RELEASE "libgdcmMSFF.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmMSFF )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmMSFF "${_IMPORT_PREFIX}/lib/libgdcmMSFF.so.1.0" )

# Import target "gdcmMEXD" for configuration "Release"
set_property(TARGET gdcmMEXD APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmMEXD PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgdcmMEXD.so.1.0"
  IMPORTED_SONAME_RELEASE "libgdcmMEXD.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmMEXD )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmMEXD "${_IMPORT_PREFIX}/lib/libgdcmMEXD.so.1.0" )

# Import target "gdcmdump" for configuration "Release"
set_property(TARGET gdcmdump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmdump PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmdump"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmdump )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmdump "${_IMPORT_PREFIX}/bin/gdcmdump" )

# Import target "gdcmdiff" for configuration "Release"
set_property(TARGET gdcmdiff APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmdiff PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmdiff"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmdiff )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmdiff "${_IMPORT_PREFIX}/bin/gdcmdiff" )

# Import target "gdcmraw" for configuration "Release"
set_property(TARGET gdcmraw APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmraw PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmraw"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmraw )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmraw "${_IMPORT_PREFIX}/bin/gdcmraw" )

# Import target "gdcmscanner" for configuration "Release"
set_property(TARGET gdcmscanner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmscanner PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmscanner"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmscanner )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmscanner "${_IMPORT_PREFIX}/bin/gdcmscanner" )

# Import target "gdcmanon" for configuration "Release"
set_property(TARGET gdcmanon APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmanon PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmanon"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmanon )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmanon "${_IMPORT_PREFIX}/bin/gdcmanon" )

# Import target "gdcmgendir" for configuration "Release"
set_property(TARGET gdcmgendir APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmgendir PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmgendir"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmgendir )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmgendir "${_IMPORT_PREFIX}/bin/gdcmgendir" )

# Import target "gdcmimg" for configuration "Release"
set_property(TARGET gdcmimg APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmimg PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmimg"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmimg )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmimg "${_IMPORT_PREFIX}/bin/gdcmimg" )

# Import target "gdcmconv" for configuration "Release"
set_property(TARGET gdcmconv APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmconv PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmconv"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmconv )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmconv "${_IMPORT_PREFIX}/bin/gdcmconv" )

# Import target "gdcmtar" for configuration "Release"
set_property(TARGET gdcmtar APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmtar PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmtar"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmtar )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmtar "${_IMPORT_PREFIX}/bin/gdcmtar" )

# Import target "gdcminfo" for configuration "Release"
set_property(TARGET gdcminfo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcminfo PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcminfo"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcminfo )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcminfo "${_IMPORT_PREFIX}/bin/gdcminfo" )

# Import target "gdcmscu" for configuration "Release"
set_property(TARGET gdcmscu APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmscu PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmscu"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmscu )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmscu "${_IMPORT_PREFIX}/bin/gdcmscu" )

# Import target "gdcmxml" for configuration "Release"
set_property(TARGET gdcmxml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmxml PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmxml"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmxml )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmxml "${_IMPORT_PREFIX}/bin/gdcmxml" )

# Import target "gdcmpap3" for configuration "Release"
set_property(TARGET gdcmpap3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmpap3 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmpap3"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmpap3 )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmpap3 "${_IMPORT_PREFIX}/bin/gdcmpap3" )

# Import target "gdcmpdf" for configuration "Release"
set_property(TARGET gdcmpdf APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gdcmpdf PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/gdcmpdf"
  )

list(APPEND _IMPORT_CHECK_TARGETS gdcmpdf )
list(APPEND _IMPORT_CHECK_FILES_FOR_gdcmpdf "${_IMPORT_PREFIX}/bin/gdcmpdf" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
